@@ -405,7 +405,7 @@ class Client:
                 "priority-normal": priority_normal,
                 "bandwidthPriority": bandwidthPriority,
                 "cookies": cookies,
-                "labels": list_or_none(labels),
+                "labels": list_or_none(_single_str_as_list(labels)),
             }
         )
 
@@ -718,7 +718,7 @@ class Client:
                 "trackerAdd": tracker_add,
                 "trackerRemove": tracker_remove,
                 "trackerReplace": tracker_replace,
-                "labels": list_or_none(labels),
+                "labels": list_or_none(_single_str_as_list(labels)),
                 "trackerList": None if tracker_list is None else "\n".join("\n\n".join(x) for x in tracker_list),
                 "group": group,
             }
@@ -1087,11 +1087,22 @@ class Client:
         *,
         timeout: Optional[_Timeout] = None,
         honors_session_limits: Optional[bool] = None,
+        speed_limit_down_enabled: Optional[bool] = None,
         speed_limit_down: Optional[int] = None,
         speed_limit_up_enabled: Optional[bool] = None,
         speed_limit_up: Optional[int] = None,
-        speed_limit_down_enabled: Optional[bool] = None,
     ) -> None:
+        """create or update a Bandwidth group.
+
+        :param name: Bandwidth group name
+        :param honors_session_limits: true if session upload limits are honored
+        :param speed_limit_down_enabled: true means enabled
+        :param speed_limit_down: 	max global download speed (KBps)
+        :param speed_limit_up_enabled: 	true means enabled
+        :param speed_limit_up: max global upload speed (KBps)
+        :param timeout: request timeout
+        """
+
         self._rpc_version_warning(17)
         arguments: Dict[str, Any] = remove_unset_value(
             {
@@ -1110,8 +1121,9 @@ class Client:
         self._rpc_version_warning(17)
         result: Dict[str, Any] = self._request(RpcMethod.GroupGet, {"group": name}, timeout=timeout)
 
-        if result["arguments"]["group"]:
-            return Group(fields=result["arguments"]["group"][0])
+        if result["group"]:
+            return Group(fields=result["group"][0])
+
         return None
 
     def get_groups(self, name: Optional[List[str]] = None, *, timeout: Optional[_Timeout] = None) -> Dict[str, Group]:
@@ -1121,7 +1133,7 @@ class Client:
 
         result: Dict[str, Any] = self._request(RpcMethod.GroupGet, payload, timeout=timeout)
 
-        return {x["name"]: Group(fields=x) for x in result["arguments"]["group"]}
+        return {x["name"]: Group(fields=x) for x in result["group"]}
 
     def __enter__(self) -> "Client":
         return self
@@ -1138,6 +1150,14 @@ class Client:
 T = TypeVar("T")
 
 
+def _single_str_as_list(v: Optional[Iterable[str]]) -> Optional[List[str]]:
+    if v is None:
+        return v
+    if isinstance(v, str):
+        return [v]
+    return list(v)
+
+
 def list_or_none(v: Optional[Iterable[T]]) -> Optional[List[T]]:
     if v is None:
         return None
